# Installation

*Requirements:* [Python](https://www.python.org/downloads/) 2.7+ or 3 is required.

Releases are hosted on [PyPI](https://pypi.python.org/pypi/fabulist) and can
be installed using [pip](http://www.pip-installer.org/):

	$ pip install fabulist
